@@ -46,19 +46,13 @@ int nxagentCheckBinder(int argc, char *argv[], int i)
 {
   if (++i < argc)
   {
-    char *display;
-    char *found;
-
-    int port;
-
-    display = argv[i];
+    char *display = argv[i];
 
     /*
-     * Check if a display specification follows
-     * the -B switch.
+     * Check if a display specification follows the -B switch.
      */
 
-    found = rindex(display, ':');
+    char *found = rindex(display, ':');
 
     if (found == NULL || *(found + 1) == '\0' ||
             isdigit(*(found + 1)) == 0)
@@ -69,7 +63,7 @@ int nxagentCheckBinder(int argc, char *argv[], int i)
       return 0;
     }
 
-    port = atoi(found + 1);
+    int port = atoi(found + 1);
 
     #ifdef TEST
     fprintf(stderr, "nxagentCheckBinder: Identified agent display port [%d].\n",
@@ -78,8 +72,8 @@ int nxagentCheckBinder(int argc, char *argv[], int i)
 
     /*
      * The NX options must be specified in the DISPLAY
-     * environment. Check if the display specified on
-     * the command line matches the NX virtual display.
+     * environment. Check if the display specified on the command line
+     * matches the NX virtual display.
      */
 
     display = getenv("DISPLAY");
@@ -108,8 +102,8 @@ int nxagentCheckBinder(int argc, char *argv[], int i)
     #endif
 
     /*
-     * Save the proxy options. They will be later
-     * used to create the transport.
+     * Save the proxy options. They will be later used to create the
+     * transport.
      */
 
     nxagentChangeOption(Rootless, False);
@@ -117,10 +111,9 @@ int nxagentCheckBinder(int argc, char *argv[], int i)
     nxagentChangeOption(Binder, True);
 
     /*
-     * FIXME: This now points to the buffer that was
-     * returned by getenv(). It is to be decided how
-     * to handle the values of type string in the
-     * Options repository.
+     * FIXME: This now points to the buffer that was returned by
+     * getenv(). It is to be decided how to handle the values of type
+     * string in the Options repository.
      */
      
     nxagentChangeOption(BinderOptions, display);
