@@ -71,6 +71,7 @@ is" without express or implied warranty.
 #include "Millis.h"
 #include "Error.h"
 #include "Keystroke.h"
+#include "Atoms.h"
 
 #include <nx/NX.h>
 #include "compext/Compext.h"
@@ -88,44 +89,35 @@ is" without express or implied warranty.
 /*
  * ProcVector array defined in tables.c.
  */
-
 extern int (*ProcVector[256])(ClientPtr);
 
 /*
  * From the fb code.
  */
-
 extern int fbGCPrivateIndex;
 
+#ifdef DPMSExtension
 /*
  * Stubs for the DPMS extension.
  */
-
-#ifdef DPMSExtension
-
 void DPMSSet(int level);
 int DPMSGet(int *level);
 Bool DPMSSupported(void);
-
 #endif
 
 /*
  * Our error logging function.
  */
-
 void OsVendorVErrorFFunction(const char *f, va_list args);
 
 /*
  * True if this is a fatal error.
  */
-
 extern int OsVendorVErrorFFatal;
 
 /*
- * Redirect the error output to a
- * different file
+ * Redirect the error output to a different file
  */
-
 extern void (*OsVendorStartRedirectErrorFProc)();
 extern void (*OsVendorEndRedirectErrorFProc)();
 
@@ -135,11 +127,8 @@ void OsVendorStartRedirectErrorFFunction();
 void OsVendorEndRedirectErrorFFunction();
 
 /*
- * Called by InitGlobals() in the
- * new X server tree.
+ * Called by InitGlobals() in the new X server tree.
  */
-
-
 static void nxagentGrabServerCallback(CallbackListPtr *callbacks, void *data,
                                    void *args);
 
@@ -148,6 +137,8 @@ extern void nxagentSetSelectionCallback(CallbackListPtr *callbacks, void *data,
                                    void *args);
 #endif
 
+extern const char *nxagentProgName;
+
 void ddxInitGlobals(void)
 {
   /*
@@ -161,12 +152,11 @@ void ddxInitGlobals(void)
 }
 
 /*
- * Set if the remote display supports
- * backing store.
+ * Set if the remote display supports backing store.
  */
 /*
-FIXME: These, if not removed, should at least
-       be moved to Display.h and Display.c.
+FIXME: These, if not removed, should at least be moved to Display.h
+       and Display.c.
 */
 int nxagentBackingStore;
 int nxagentSaveUnder;
@@ -184,7 +174,6 @@ int nxagentSaveUnder;
  *         nxagentOpenScreen
  *   InitInput
  */
-
 int nxagentDoFullGeneration = 1;
 
  /*
@@ -194,13 +183,10 @@ int nxagentDoFullGeneration = 1;
 Bool nxagentX2go;
 
 /*
- * Check if agent is x2go agent
+ * Check if agent is X2goAgent
  */
-
 void checkX2goAgent(void)
 {
-  extern const char *nxagentProgName;
-
   #ifdef TEST
   fprintf(stderr, "%s: nxagentProgName [%s]\n", __func__, nxagentProgName);
   #endif
@@ -214,22 +200,11 @@ void checkX2goAgent(void)
     nxagentX2go = False;
 }
 
-
 /*
  * Called at X server's initialization.
  */
-
-void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
+void InitOutput(ScreenInfo *scrInfo, int argc, char *argv[])
 {
-  char *authority;
-  int i;
-
-  #ifdef __sun
-
-  char *environment;
-
-  #endif
-
   /*
    * Print our pid and version information.
    */
@@ -252,8 +227,8 @@ void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
   }
 
   /*
-   * Avoid slowness due to buggy_repeat workaround
-   * in libcairo versions >= 1.10.
+   * Avoid slowness due to buggy_repeat workaround in libcairo
+   * versions >= 1.10.
    */
 
   SetVendorRelease(70000000);
@@ -268,9 +243,8 @@ void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
   }
 
   /*
-   * Unset the LD_LIBRARY_PATH variable in
-   * Popen() before calling execl() in the
-   * child process.
+   * Unset the LD_LIBRARY_PATH variable in Popen() before calling
+   * execl() in the child process.
    */
 
   NXUnsetLibraryPath(1);
@@ -295,11 +269,13 @@ void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
   }
   #endif
 
-  if ((authority = getenv("NX_XAUTHORITY")))
+  char *authority = getenv("NX_XAUTHORITY");
+
+  if (authority)
   {
     #ifdef __sun
 
-    environment = malloc(15 + strlen(authority));
+    char *environment = malloc(15 + strlen(authority));
 
     sprintf(environment, "XAUTHORITY=%s", authority);
 
@@ -320,15 +296,13 @@ void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
   nxagentInitBSPixmapList();
 
   /*
-   * Open the display. We are at the early startup and
-   * the information we'll get from the remote X server
-   * will mandate some of the characteristics of the
-   * session, like the screen depth. Note that this re-
-   * liance on the remote display at session startup
-   * should be removed. We should always operate at 32
-   * bpp, internally, and do the required translations
-   * as soon as the graphic operation needs to be real-
-   * ized on the remote display.
+   * Open the display. We are at the early startup and the information
+   * we'll get from the remote X server will mandate some of the
+   * characteristics of the session, like the screen depth. Note that
+   * this reliance on the remote display at session startup should be
+   * removed. We should always operate at 32 bpp, internally, and do
+   * the required translations as soon as the graphic operation needs
+   * to be realized on the remote display.
    */
 
   nxagentOpenDisplay(argc, argv);
@@ -355,13 +329,13 @@ FIXME: These variables, if not removed at all because have probably
    * Initialize the basic screen info.
    */
 
-  nxagentSetScreenInfo(screenInfo);
+  nxagentSetScreenInfo(scrInfo);
 
   /*
    * Initialize pixmap formats for this screen.
    */
 
-  nxagentSetPixmapFormats(screenInfo);
+  nxagentSetPixmapFormats(scrInfo);
 
   /*
    * Get our own privates' index.
@@ -391,17 +365,16 @@ FIXME: These variables, if not removed at all because have probably
     nxagentNumScreens = 1;
   }
 
-  for (i = 0; i < nxagentNumScreens; i++)
+  for (int i = 0; i < nxagentNumScreens; i++)
   {
     AddScreen(nxagentOpenScreen, argc, argv);
   }
 
-  nxagentNumScreens = screenInfo->numScreens;
+  nxagentNumScreens = scrInfo->numScreens;
 
   /*
-   * Initialize the GCs used by the synchro-
-   * nization put images. We do it here beca-
-   * use we use the nxagentDefaultScreen.
+   * Initialize the GCs used by the synchronization put images. We do
+   * it here because we use the nxagentDefaultScreen.
    */
 
   nxagentAllocateGraphicContexts();
@@ -409,8 +382,7 @@ FIXME: These variables, if not removed at all because have probably
   nxagentDoFullGeneration = nxagentFullGeneration;
 
   /*
-   * Use a solid black root window
-   * background.
+   * Use a solid black root window background.
    */
 
   if (!whiteRoot)
@@ -421,17 +393,16 @@ FIXME: These variables, if not removed at all because have probably
 #ifdef NXAGENT_CLIPBOARD
   AddCallback(&SelectionCallback, nxagentSetSelectionCallback, NULL);
 #endif
+
+  nxagentInitAtoms();
 }
 
-void
-nxagentNotifyConnection(int fd, int ready, void *data)
+void nxagentNotifyConnection(int fd, int ready, void *data)
 {
     nxagentDispatchEvents(NULL);
 }
 
-void InitInput(argc, argv)
-     int argc;
-     char *argv[];
+void InitInput(int argc, char *argv[])
 {
   void *ptr, *kbd;
 
@@ -444,9 +415,8 @@ void InitInput(argc, argv)
   mieqInit(kbd, ptr);
 
   /*
-   * Add the display descriptor to the
-   * set of descriptors awaited by the
-   * dispatcher.
+   * Add the display descriptor to the set of descriptors awaited by
+   * the dispatcher.
    */
 
   nxagentAddXConnection();
@@ -461,10 +431,9 @@ void InitInput(argc, argv)
   }
 
   /*
-   * We let the proxy flush the link on our behalf
-   * after having opened the display. We are now
-   * entering the dispatcher. From now on we'll
-   * flush the proxy link explicitly.
+   * We let the proxy flush the link on our behalf after having opened
+   * the display. We are now entering the dispatcher. From now on
+   * we'll flush the proxy link explicitly.
    */
 
   #ifdef TEST
@@ -475,11 +444,9 @@ void InitInput(argc, argv)
 }
 
 /*
- * DDX specific abort routine. This is called
- * by AbortServer() that, in turn, is called
- * by FatalError().
+ * DDX specific abort routine. This is called by AbortServer() that,
+ * in turn, is called by FatalError().
  */
-
 void AbortDDX(void)
 {
   nxagentDoFullGeneration = True;
@@ -487,9 +454,8 @@ void AbortDDX(void)
   nxagentCloseDisplay();
 
   /*
-   * Do the required finalization if we
-   * are not going through the normal
-   * X server shutdown.
+   * Do the required finalization if we are not going through the
+   * normal X server shutdown.
    */
 
   if ((dispatchException & DE_TERMINATE) == 0)
@@ -501,7 +467,6 @@ void AbortDDX(void)
 /*
  * Called by GiveUp().
  */
-
 void ddxGiveUp(void)
 {
   AbortDDX();
@@ -519,12 +484,10 @@ void OsVendorInit(void)
 void OsVendorFatalError(void)
 {
   /*
-   * Let the session terminate gracely
-   * from an user's standpoint.
+   * Let the session terminate gracely from an user's standpoint.
    */
 
   fprintf(stderr, "Session: Aborting session at '%s'.\n", GetTimeAsString());
-
   fprintf(stderr, "Session: Session aborted at '%s'.\n", GetTimeAsString());
 }
 
@@ -570,7 +533,6 @@ static void nxagentGrabServerCallback(CallbackListPtr *callbacks, void *data,
 }
 
 #ifdef DPMSExtension
-
 void DPMSSet(int level)
 {
 }
@@ -584,5 +546,4 @@ Bool DPMSSupported(void)
 {
   return 0;
 }
-
 #endif
