@@ -432,9 +432,9 @@ void nxagentDumpKeystrokes(void)
 {
   int maxlen = 0;
   for (int i = 0; nxagentSpecialKeystrokeNames[i]; i++)
-    maxlen = min(maxlen, strlen(nxagentSpecialKeystrokeNames[i]));
+    maxlen = max(maxlen, strlen(nxagentSpecialKeystrokeNames[i]));
 
-  fprintf(stderr, "Current known keystrokes:\n");
+  fprintf(stderr, "Currently known keystrokes:\n");
 
   for (struct nxagentSpecialKeystrokeMap *cur = map; cur->stroke != KEYSTROKE_END_MARKER; cur++) {
     unsigned int mask = cur->modifierMask;
