@@ -88,6 +88,19 @@ typedef struct
 nxagentWMStateRec;
 #endif
 
+#define PANIC
+#define WARNING
+#undef  TEST
+#undef  DEBUG
+
+#ifdef NXAGENT_CLIPBOARD
+extern WindowPtr nxagentGetClipboardWindow(Atom);
+#endif
+
+#ifdef NXAGENT_ARTSD
+extern Atom mcop_local_atom;
+#endif
+
 int 
 ProcChangeProperty(ClientPtr client)
 {	      
@@ -122,11 +135,7 @@ ProcChangeProperty(ClientPtr client)
     REQUEST_FIXED_SIZE(xChangePropertyReq, totalSize);
 
 #ifdef NXAGENT_CLIPBOARD
-    {
-       extern WindowPtr nxagentGetClipboardWindow(Atom, WindowPtr);
-
-       pWin = nxagentGetClipboardWindow(stuff->property, NULL);
-    }
+    pWin = nxagentGetClipboardWindow(stuff->property);
 
     if (pWin == NULL)
 #endif
@@ -163,7 +172,6 @@ ProcChangeProperty(ClientPtr client)
       they are already set reflecting the server side settings.
       Just return success.
     */
-      extern Atom mcop_local_atom;
       if (stuff->property == mcop_local_atom)
         return client->noClientException;
     }
@@ -207,16 +215,9 @@ ChangeWindowProperty(WindowPtr pWin, Atom property, Atom type, int format,
                      int mode, unsigned long len, void * value, 
                      Bool sendevent)
 {
-    PropertyPtr pProp;
-    int sizeInBytes;
-    int totalSize;
-    void * data;
-    int copySize;
-
-    sizeInBytes = format>>3;
-    totalSize = len * sizeInBytes;
-
-    copySize = nxagentOption(CopyBufferSize);
+    int sizeInBytes = format>>3;
+    int totalSize = len * sizeInBytes;
+    int copySize = nxagentOption(CopyBufferSize);
 
     if (copySize != COPY_UNLIMITED && property == clientCutProperty)
     {
@@ -228,105 +229,7 @@ ChangeWindowProperty(WindowPtr pWin, Atom property, Atom type, int format,
       }
     }
 
-    /* first see if property already exists */
-
-    pProp = wUserProps (pWin);
-    while (pProp)
-    {
-	if (pProp->propertyName == property)
-	    break;
-	pProp = pProp->next;
-    }
-    if (!pProp)   /* just add to list */
-    {
-	if (!pWin->optional && !MakeWindowOptional (pWin))
-	    return(BadAlloc);
-        pProp = (PropertyPtr)malloc(sizeof(PropertyRec));
-	if (!pProp)
-	    return(BadAlloc);
-        data = (void *)malloc(totalSize);
-	if (!data && len)
-	{
-	    free(pProp);
-	    return(BadAlloc);
-	}
-        pProp->propertyName = property;
-        pProp->type = type;
-        pProp->format = format;
-        pProp->data = data;
-	if (len)
-	    memmove((char *)data, (char *)value, totalSize);
-	pProp->size = len;
-        pProp->next = pWin->optional->userProps;
-        pWin->optional->userProps = pProp;
-    }
-    else
-    {
-	/* To append or prepend to a property the request format and type
-		must match those of the already defined property.  The
-		existing format and type are irrelevant when using the mode
-		"PropModeReplace" since they will be written over. */
-
-        if ((format != pProp->format) && (mode != PropModeReplace))
-	    return(BadMatch);
-        if ((pProp->type != type) && (mode != PropModeReplace))
-            return(BadMatch);
-        if (mode == PropModeReplace)
-        {
-	    if (totalSize != pProp->size * (pProp->format >> 3))
-	    {
-		data = (void *)realloc(pProp->data, totalSize);
-	    	if (!data && len)
-		    return(BadAlloc);
-            	pProp->data = data;
-	    }
-	    if (len)
-		memmove((char *)pProp->data, (char *)value, totalSize);
-	    pProp->size = len;
-    	    pProp->type = type;
-	    pProp->format = format;
-	}
-	else if (len == 0)
-	{
-	    /* do nothing */
-	}
-        else if (mode == PropModeAppend)
-        {
-	    data = (void *)realloc(pProp->data,
-				     sizeInBytes * (len + pProp->size));
-	    if (!data)
-		return(BadAlloc);
-            pProp->data = data;
-	    memmove(&((char *)data)[pProp->size * sizeInBytes], 
-		    (char *)value,
-		  totalSize);
-            pProp->size += len;
-	}
-        else if (mode == PropModePrepend)
-        {
-            data = (void *)malloc(sizeInBytes * (len + pProp->size));
-	    if (!data)
-		return(BadAlloc);
-	    memmove(&((char *)data)[totalSize], (char *)pProp->data, 
-		  (int)(pProp->size * sizeInBytes));
-            memmove((char *)data, (char *)value, totalSize);
-	    free(pProp->data);
-            pProp->data = data;
-            pProp->size += len;
-	}
-    }
-    if (sendevent)
-    {
-	xEvent event;
-	memset(&event, 0, sizeof(xEvent));
-	event.u.u.type = PropertyNotify;
-	event.u.property.window = pWin->drawable.id;
-	event.u.property.state = PropertyNewValue;
-	event.u.property.atom = pProp->propertyName;
-	event.u.property.time = currentTime.milliseconds;
-	DeliverEvents(pWin, &event, 1, (WindowPtr)NULL);
-    }
-    return(Success);
+    return Xorg_ChangeWindowProperty(pWin, property, type, format, mode, len, value, sendevent);
 }
 
 /*****************
@@ -544,14 +447,17 @@ ProcGetProperty(ClientPtr client)
 
 #ifdef NXAGENT_CLIPBOARD
 /* GetWindowProperty clipboard use only */
+/* FIXME: that's wrong, it is also called in Window.c and Events. */
+/* FIXME: should be moved to a different file, is not derived from
+   dix */
 int
 GetWindowProperty(pWin, property, longOffset, longLength, delete,
             type, actualType, format, nItems, bytesAfter, propData )
     WindowPtr	        pWin;
     Atom		property;
-    long			longOffset;
-    long			longLength;
-    Bool			delete;
+    long		longOffset;
+    long		longLength;
+    Bool		delete;
     Atom		type;
     Atom		*actualType;
     int			*format;
@@ -563,15 +469,25 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
     unsigned long n, len, ind;
 
     if (!pWin)
+    {
+        #ifdef DEBUG
+	fprintf(stderr, "%s: invalid window\n", __func__);
+        #endif
 	return BadWindow;
-
+    }
 
     if (!ValidAtom(property))
     {
+        #ifdef DEBUG
+	fprintf(stderr, "%s: invalid atom [%d]\n", __func__, property);
+        #endif
 	return(BadAtom);
     }
     if ((type != AnyPropertyType) && !ValidAtom(type))
     {
+        #ifdef DEBUG
+	fprintf(stderr, "%s: invalid type [%d]\n", __func__, type);
+        #endif
 	return(BadAtom);
     }
 
@@ -588,10 +504,15 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
 
 
     if (!pProp)
+    {
+        #ifdef DEBUG
+	fprintf(stderr, "%s: property not found [%d]\n", __func__, property);
+        #endif
 	return (BadAtom);
+    }
 
     /* If the request type and actual type don't match. Return the
-    property information, but not the data. */
+       property information, but not the data. */
 
     if (((type != pProp->type) &&
 	 (type != AnyPropertyType))
@@ -604,17 +525,20 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
 	return(Success);
     }
 
-/*
- *  Return type, format, value to client
- */
+    /*
+     *  Return type, format, value to client
+     */
     n = (pProp->format/8) * pProp->size; /* size (bytes) of prop */
     ind = longOffset << 2;
 
-   /* If longOffset is invalid such that it causes "len" to
-	    be negative, it's a value error. */
+    /* If longOffset is invalid such that it causes "len" to
+       be negative, it's a value error. */
 
     if (n < ind)
     {
+        #ifdef DEBUG
+	fprintf(stderr, "%s: negative property len\n", __func__);
+        #endif
 	return BadValue;
     }
 
@@ -627,9 +551,7 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
 
     if (delete && (*bytesAfter == 0))
     { /* send the event */
-	xEvent event;
-
-	memset(&event, 0, sizeof(xEvent));
+	xEvent event = {0};
 	event.u.u.type = PropertyNotify;
 	event.u.property.window = pWin->drawable.id;
 	event.u.property.state = PropertyDelete;
@@ -640,7 +562,7 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
 
     if (len)
     {
-	 *propData = (unsigned char *)(pProp->data) + ind;
+	*propData = (unsigned char *)(pProp->data) + ind;
     }
 
     if (delete && (*bytesAfter == 0))
@@ -658,3 +580,50 @@ GetWindowProperty(pWin, property, longOffset, longLength, delete,
     return(Success);
 }
 #endif
+
+int
+ProcDeleteProperty(register ClientPtr client)
+{
+    WindowPtr pWin;
+    REQUEST(xDeletePropertyReq);
+    int result;
+
+    REQUEST_SIZE_MATCH(xDeletePropertyReq);
+    UpdateCurrentTime();
+    pWin = (WindowPtr)SecurityLookupWindow(stuff->window, client,
+                                           DixWriteAccess);
+    if (!pWin)
+        return(BadWindow);
+    if (!ValidAtom(stuff->property))
+    {
+        client->errorValue = stuff->property;
+        return (BadAtom);
+    }
+
+#ifdef XCSECURITY
+    switch(SecurityCheckPropertyAccess(client, pWin, stuff->property,
+                                       DixDestroyAccess))
+    {
+        case SecurityErrorOperation:
+            client->errorValue = stuff->property;
+            return BadAtom;;
+        case SecurityIgnoreOperation:
+            return Success;
+    }
+#endif
+
+#ifdef NXAGENT_SERVER
+    /* prevent clients from deleting the NX_AGENT_VERSION property */
+    {
+      Atom prop = MakeAtom("NX_AGENT_VERSION", strlen("NX_AGENT_VERSION"), True);
+      if (stuff->property == prop)
+        return client->noClientException;
+    }
+#endif
+
+    result = DeleteProperty(pWin, stuff->property);
+    if (client->noClientException != Success)
+        return(client->noClientException);
+    else
+        return(result);
+}
