@@ -66,8 +66,8 @@ is" without express or implied warranty.
 #undef  DEBUG
 
 /*
- * The nxagentReversePointerMap array is used to
- * memorize remote display pointer map.
+ * The nxagentReversePointerMap array is used to memorize remote
+ * display pointer map.
  */
 
 unsigned char nxagentReversePointerMap[MAXBUTTONS];
@@ -76,19 +76,18 @@ void nxagentChangePointerControl(DeviceIntPtr pDev, PtrCtrl *ctrl)
 {
   /*
    * The original behaviour was to reset the pointer settings
-   * (acceleration and alas) to the default values. What the
-   * average user expects, on the contrary, is to have agent
-   * inheriting whatever value is set on the real X display.
-   * Having to reflect changes made inside the agent session,
-   * the correct behavior would be saving the original values
-   * and restoring them as soon as focus leaves the agent's
-   * window.
+   * (acceleration and alas) to the default values. What the average
+   * user expects, on the contrary, is to have agent inheriting
+   * whatever value is set on the real X display.  Having to reflect
+   * changes made inside the agent session, the correct behavior would
+   * be saving the original values and restoring them as soon as focus
+   * leaves the agent's window.
    */
 
   if (nxagentOption(DeviceControl) == True)
   {
     #ifdef TEST
-    fprintf(stderr, "nxagentChangePointerControl: WARNING! Propagating changes to pointer settings.\n");
+    fprintf(stderr, "%s: WARNING! Propagating changes to pointer settings.\n", __func__);
     #endif
 
     XChangePointerControl(nxagentDisplay, True, True, 
@@ -98,22 +97,18 @@ void nxagentChangePointerControl(DeviceIntPtr pDev, PtrCtrl *ctrl)
   }
 
   #ifdef TEST
-  fprintf(stderr, "nxagentChangePointerControl: WARNING! Not propagating changes to pointer settings.\n");
+  fprintf(stderr, "%s: WARNING! Not propagating changes to pointer settings.\n", __func__);
   #endif
 }
 
 int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
 {
-  CARD8 map[MAXBUTTONS];
-  int nmap;
-  int i;
-
   switch (onoff)
   {
     case DEVICE_INIT:
 
       #ifdef TEST
-      fprintf(stderr, "nxagentPointerProc: Called for [DEVICE_INIT].\n");
+      fprintf(stderr, "%s: Called for [DEVICE_INIT].\n", __func__);
       #endif
 
       if (NXDisplayError(nxagentDisplay) == 1)
@@ -121,8 +116,10 @@ int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
         return Success;
       }
 
-      nmap = XGetPointerMapping(nxagentDisplay, map, MAXBUTTONS);
-      for (i = 0; i <= nmap; i++)
+      CARD8 map[MAXBUTTONS];
+
+      int nmap = XGetPointerMapping(nxagentDisplay, map, MAXBUTTONS);
+      for (int i = 0; i <= nmap; i++)
 	map[i] = i; /* buttons are already mapped */
       InitPointerDeviceStruct((DevicePtr) pDev, map, nmap,
 			      miPointerGetMotionEvents,
@@ -132,7 +129,7 @@ int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
     case DEVICE_ON:
 
       #ifdef TEST
-      fprintf(stderr, "nxagentPointerProc: Called for [DEVICE_ON].\n");
+      fprintf(stderr, "%s: Called for [DEVICE_ON].\n", __func__);
       #endif
 
       if (NXDisplayError(nxagentDisplay) == 1)
@@ -149,7 +146,7 @@ int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
     case DEVICE_OFF:
 
       #ifdef TEST
-      fprintf(stderr, "nxagentPointerProc: Called for [DEVICE_OFF].\n");
+      fprintf(stderr, "%s: Called for [DEVICE_OFF].\n", __func__);
       #endif
 
       if (NXDisplayError(nxagentDisplay) == 1)
@@ -163,7 +160,7 @@ int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
 
     case DEVICE_CLOSE:
       #ifdef TEST
-      fprintf(stderr, "nxagentPointerProc: Called for [DEVICE_CLOSE].\n");
+      fprintf(stderr, "%s: Called for [DEVICE_CLOSE].\n", __func__);
       #endif
 
       break;
@@ -174,24 +171,20 @@ int nxagentPointerProc(DeviceIntPtr pDev, int onoff)
 
 void nxagentInitPointerMap(void)
 {
-  int numButtons;
-
-  int i;
-
   unsigned char pointerMap[MAXBUTTONS];
 
   #ifdef DEBUG
-  fprintf(stderr, "nxagentInitPointerMap: Going to retrieve the "
-              "pointer map from remote display.\n");
+  fprintf(stderr, "%s: Going to retrieve the "
+	  "pointer map from remote display.\n", __func__);
   #endif
 
-  numButtons = XGetPointerMapping(nxagentDisplay, pointerMap, MAXBUTTONS);
+  int numButtons = XGetPointerMapping(nxagentDisplay, pointerMap, MAXBUTTONS);
 
   /*
-   * Computing revers pointer map.
+   * Computing reverse pointer map.
    */
 
-  for (i = 1; i <= numButtons; i++)
+  for (int i = 1; i <= numButtons; i++)
   {
     nxagentReversePointerMap[pointerMap[i - 1]] = i;
   }
