@@ -83,7 +83,7 @@ extern Bool nxagentReconnectAllPicture(void*);
 
 extern Bool nxagentDisconnectAllPicture(void);
 extern Bool nxagentDisconnectAllWindows(void);
-extern Bool nxagentDisconnectAllCursor(void);
+extern void nxagentDisconnectAllCursor(void);
 
 extern Bool nxagentReconnectFailedFonts(void*);
 extern Bool nxagentInstallFontServerPath(void);
@@ -458,15 +458,6 @@ Bool nxagentReconnectSession(void)
 
   nxagentProcessOptions(nxagentOptionsFilenameOrString);
 
-  if (nxagentKeyboard && (strcmp(nxagentKeyboard, "null/null") == 0))
-  {
-    #ifdef TEST
-    fprintf(stderr, "nxagentReconnect: changing nxagentKeyboard from [null/null] to [clone].\n");
-    #endif
-
-    SAFE_free(nxagentKeyboard);
-    nxagentKeyboard = strdup("clone");
-  }
 
   if (nxagentReconnectDisplay(reconnectLossyLevel[DISPLAY_STEP]) == 0)
   {
@@ -528,6 +519,7 @@ Bool nxagentReconnectSession(void)
 
   nxagentEmptyBSPixmapList();
 
+  /* FIXME: nxagentReconnectAllPixmaps will always return 1 */
   if (nxagentReconnectAllPixmaps(reconnectLossyLevel[PIXMAP_STEP]) == 0)
   {
     failedStep = PIXMAP_STEP;
@@ -608,29 +600,34 @@ Bool nxagentReconnectSession(void)
     nxagentOldKeyboard = NULL;
   }
 
-  if (nxagentOption(ResetKeyboardAtResume) == 1 &&
-         (nxagentKeyboard  == NULL || nxagentOldKeyboard == NULL ||
-             strcmp(nxagentKeyboard, nxagentOldKeyboard) != 0 ||
-                 strcmp(nxagentKeyboard, "query") == 0 ||
-                     strcmp(nxagentKeyboard, "clone") == 0))
+  /* Reset the keyboard only if we detect any changes. */
+  if (nxagentOption(ResetKeyboardAtResume) == 1)
   {
-    if (nxagentResetKeyboard() == 0)
+    if (nxagentKeyboard == NULL || nxagentOldKeyboard == NULL ||
+            strcmp(nxagentKeyboard, nxagentOldKeyboard) != 0 ||
+                strcmp(nxagentKeyboard, "query") == 0 ||
+                    strcmp(nxagentKeyboard, "clone") == 0)
     {
-      #ifdef WARNING
-      if (nxagentVerbose == 1)
+      if (nxagentResetKeyboard() == 0)
       {
-        fprintf(stderr, "nxagentReconnectSession: Failed to reset keyboard device.\n");
+        #ifdef WARNING
+        if (nxagentVerbose == 1)
+        {
+          fprintf(stderr, "%s: Failed to reset keyboard device.\n", __func__);
+        }
+        #endif
+
+        failedStep = WINDOW_STEP;
+
+        goto nxagentReconnectError;
       }
-      #endif
-
-      failedStep = WINDOW_STEP;
-
-      goto nxagentReconnectError;
     }
-  }
-  else
-  {
-    nxagentKeycodeConversionSetup();
+    else
+    {
+      #ifdef DEBUG
+      fprintf(stderr, "%s: keyboard unchanged - skipping keyboard reset.\n", __func__);
+      #endif
+    }
   }
 
   nxagentXkbState.Initialized = 0;
@@ -670,7 +667,7 @@ Bool nxagentReconnectSession(void)
   }
 
   /* Re-read keystrokes definitions in case the keystrokes file has
-     changed while being supended */
+     changed while being suspended */
   nxagentInitKeystrokes(True);
 
   #ifdef NX_DEBUG_INPUT
