@@ -83,9 +83,6 @@ OR PERFORMANCE OF THIS SOFTWARE.
 #include <signal.h>
 #endif
 
-#if defined(WIN32) && !defined(__CYGWIN__)
-#include <nx-X11/Xwinsock.h>
-#endif
 #include <nx-X11/Xos.h>
 #include <stdio.h>
 #include "misc.h"
@@ -115,10 +112,8 @@ OR PERFORMANCE OF THIS SOFTWARE.
 #undef _POSIX_SOURCE
 #endif
 #endif
-#ifndef WIN32
 #include <sys/wait.h>
-#endif
-#if !defined(SYSV) && !defined(WIN32)
+#if !defined(SYSV)
 #include <sys/resource.h>
 #endif
 #include <time.h>
@@ -132,9 +127,7 @@ OR PERFORMANCE OF THIS SOFTWARE.
 #include <stdlib.h>	/* for malloc() */
 
 #if defined(TCPCONN)
-# ifndef WIN32
 #  include <netdb.h>
-# endif
 #endif
 
 #include "opaque.h"
@@ -271,6 +264,14 @@ long Memory_fail = 0;
 char *dev_tty_from_init = NULL;		/* since we need to parse it anyway */
 #endif
 
+#ifdef NXAGENT_SERVER
+extern const char *nxagentProgName;
+#endif
+
+#ifdef NX_TRANS_SOCKET
+extern char **environ;
+#endif
+
 extern char dispatchExceptionAtReset;
 
 /* Extension enable/disable in miinitext.c */
@@ -554,7 +555,6 @@ AdjustWaitForDelay (void * waitTime, unsigned long newdelay)
 void UseMsg(void)
 {
 #ifdef NXAGENT_SERVER
-    extern const char *nxagentProgName;
     ErrorF("Usage: %s [<options>] [:<display>]\n\n", nxagentProgName);
 #else
     ErrorF("use: X [:<display>] [option]\n");
@@ -903,7 +903,7 @@ ProcessCommandLine(int argc, char *argv[])
 #ifdef SERVER_LOCK
 	else if ( strcmp ( argv[i], "-nolock") == 0)
 	{
-#if !defined(WIN32) && !defined(__CYGWIN__)
+#if  !defined(__CYGWIN__)
 	  if (getuid() != 0)
 	    ErrorF("Warning: the -nolock option can only be used by root\n");
 	  else
@@ -1223,7 +1223,7 @@ ExpandCommandLine(int *pargc, char ***pargv)
 {
     int i;
 
-#if !defined(WIN32) && !defined(__CYGWIN__)
+#if  !defined(__CYGWIN__)
     if (getuid() != geteuid())
 	return;
 #endif
@@ -1559,7 +1559,6 @@ OsReleaseSignals (void)
 #endif
 }
 
-#if !defined(WIN32)
 /*
  * "safer" versions of system(3), popen(3) and pclose(3) which give up
  * all privs before running a command.
@@ -1731,8 +1730,6 @@ Popen(char *command, char *type)
 
           #else
 
-          extern char **environ;
-
           char **ep = environ;
 
           ep = environ;
@@ -1943,7 +1940,6 @@ Fclose(void * iop)
 #endif
 }
 
-#endif /* !WIN32 */
 
 
 /*
@@ -1976,11 +1972,7 @@ Fclose(void * iop)
 
 /* Check args and env only if running setuid (euid == 0 && euid != uid) ? */
 #ifndef CHECK_EUID
-#ifndef WIN32
 #define CHECK_EUID 1
-#else
-#define CHECK_EUID 0
-#endif
 #endif
 
 /*
@@ -2227,52 +2219,3 @@ CheckUserAuthorization(void)
 #endif
 }
 
-#ifdef __SCO__
-#include <fcntl.h>
-
-static void
-lockit (int fd, short what)
-{
-  struct flock lck;
-
-  lck.l_whence = 0;
-  lck.l_start = 0;
-  lck.l_len = 1;
-  lck.l_type = what;
-
-  (void)fcntl (fd, F_SETLKW, &lck);
-}
-
-/* SCO OpenServer 5 lacks pread/pwrite. Emulate them. */
-ssize_t
-pread (int fd, void *buf, size_t nbytes, off_t offset)
-{
-  off_t saved;
-  ssize_t ret;
-
-  lockit (fd, F_RDLCK);
-  saved = lseek (fd, 0, SEEK_CUR);
-  lseek (fd, offset, SEEK_SET);
-  ret = read (fd, buf, nbytes);
-  lseek (fd, saved, SEEK_SET);
-  lockit (fd, F_UNLCK);
-
-  return ret;
-}
-
-ssize_t
-pwrite (int fd, const void *buf, size_t nbytes, off_t offset)
-{
-  off_t saved;
-  ssize_t ret;
-
-  lockit (fd, F_WRLCK);
-  saved = lseek (fd, 0, SEEK_CUR);
-  lseek (fd, offset, SEEK_SET);
-  ret = write (fd, buf, nbytes);
-  lseek (fd, saved, SEEK_SET);
-  lockit (fd, F_UNLCK);
-
-  return ret;
-}
-#endif /* __SCO__ */
