@@ -26,8 +26,6 @@
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
-#elif defined(HAVE_CONFIG_H)
-#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -35,7 +33,6 @@
 #include <stdlib.h>
 #include <nx-X11/Xfuncs.h>
 
-
 #include <nx-X11/X.h>
 #include <nx-X11/keysym.h>
 #include <nx-X11/Xproto.h>
@@ -46,8 +43,7 @@
 #include <xkbsrv.h>
 
 #include "xkbgeom.h"
-#include "xkbfile.h"
-
+#include <xkbfile.h>
 
 #define	VMOD_HIDE_VALUE	0
 #define	VMOD_SHOW_VALUE	1
